From 26e78ffeec2d066f0a80ffff5bd927a76ee00bb5 Mon Sep 17 00:00:00 2001
From: Juraj Hercek <redacted@due.to.spam>
Date: Sat, 22 Jan 2022 15:34:36 +0100
Subject: [PATCH 2/4] Add Makefile for plainrsa-gen utility

The plainrsa-gen utility is not included in NetBSD distribution. This
patch introduces changes that allow us to build and distribute
plainrsa-gen including the manual page.
---
 usr.sbin/Makefile              |  2 +-
 usr.sbin/plainrsa-gen/Makefile | 36 ++++++++++++++++++++++++++++++++++
 2 files changed, 37 insertions(+), 1 deletion(-)
 create mode 100644 usr.sbin/plainrsa-gen/Makefile

diff --git a/usr.sbin/Makefile b/usr.sbin/Makefile
index 5762e78c7..2563e32d6 100644
--- a/usr.sbin/Makefile
+++ b/usr.sbin/Makefile
@@ -52,7 +52,7 @@ SUBDIR+=faithd ifmcstat ip6addrctl ndp rip6query rtsold
 SUBDIR+=mld6query route6d rtadvd traceroute6 
 .endif
 
-SUBDIR+= racoon racoonctl
+SUBDIR+= racoon racoonctl plainrsa-gen
 
 SUBDIR+= nvmmctl
 
diff --git a/usr.sbin/plainrsa-gen/Makefile b/usr.sbin/plainrsa-gen/Makefile
new file mode 100644
index 000000000..9e7c38c05
--- /dev/null
+++ b/usr.sbin/plainrsa-gen/Makefile
@@ -0,0 +1,36 @@
+# $NetBSD: Makefile,v 0.0 2022/01/22 15:32:00 juhe Exp $
+
+WARNS?=	0	# XXX third-party program, many issues
+NOCLANGERROR=	# defined
+
+.include <bsd.own.mk>
+
+PROG=	plainrsa-gen
+SRCS=	plainrsa-gen.c plog.c crypto_openssl.c logger.c vmbuf.c misc.c \
+		rsalist.c sockmisc.c genlist.c prsa_tok.l prsa_par.y
+MAN=	plainrsa-gen.8
+
+DIST=	${NETBSDSRCDIR}/crypto/dist/ipsec-tools
+#CFLAGS+=-g
+CPPFLAGS+= -I${DIST}/src/racoon -I${DIST}/src/racoon/missing
+CPPFLAGS+= -I${DIST}/src/libipsec
+CPPFLAGS+= -I${NETBSDSRCDIR}/lib/libipsec
+CPPFLAGS+=	-DHAVE_CONFIG_H -DNOUSE_PRIVSEP
+.if ${HAVE_OPENSSL} < 11
+CPPFLAGS+= -DHAVE_OPENSSL_RC5_H
+CPPFLAGS+= -DOPENSSL_API_COMPAT=0x10100000L
+.endif
+
+.PATH:  ${DIST}/src/racoon
+
+LDADD+= -lcrypto -lipsec
+DPADD+= ${LIBCRYPT}
+
+prsa_tok.c: ${DIST}/src/racoon/prsa_tok.l
+	${LEX} -Pprsa -o${.TARGET} ${.ALLSRC}
+
+prsa_par.c: ${DIST}/src/racoon/prsa_par.y
+	${YACC} -pprsa -d -o ${.TARGET} ${.ALLSRC}
+
+.include <bsd.prog.mk>
+
-- 
2.34.1

